---

slug: /time-type
---

# TIME type

The `TIME` type can represent a specific time of day, as well as the duration or time interval between two events (which may be much longer than 24 hours).

seekdb allows you to assign values to `TIME` columns using strings or numbers.

`TIME` values are retrieved and displayed in the `'hh:mm:ss'` format, ranging from '-838:59:59' to '838:59:59'.

The display format of `TIME` values can also include the fractional part of seconds, in the `'hh:mm:ss[.fraction]'` format, with a precision of up to microseconds (6 digits), ranging from '-838:59:59.000000' to '838:59:59.000000'. The fractional part must always be separated from the time digits by a decimal point, and other separators are not recognized.

The syntax for `TIME` is as follows:

```sql
TIME[(fsp)]
```

The optional `fsp` value specifies the precision of the fractional part of seconds, ranging from \[0,6\]. A value of 0 indicates no fractional part. If omitted, the default precision is 0.